@@ -1,6 +1,6 @@
 import logging
 from pathlib import Path
-from typing import Any, Dict, List, Optional
+from typing import Any, Dict, List, Optional, Union
 
 import torch
 from fairscale.nn.data_parallel import FullyShardedDataParallel as FSDP
@@ -120,8 +120,9 @@ class FairScaleTrainingEngine(TorchTrainingEngine):
         if amp:
             self.grad_scaler = ShardedGradScaler()
 
-    def _construct_model(self, model: Lazy[Model]) -> Model:
-        model: Model = model.construct()
+    def _construct_model(self, model: Union[Model, Lazy[Model]]) -> Model:
+        if isinstance(model, Lazy):
+            model = model.construct()
         if not self.fsdp_config.move_params_to_cpu:
             model.to(self.train_config.worker_local_default_device)
         return FSDP(model, **self.fsdp_config.as_kwargs())
