@@ -98,12 +98,16 @@ library under the corresponding class from the `torch <torch.html>`_ integration
             transformers::AutoModelForTableQuestionAnswering::from_pretrained
             transformers::AutoModelForTokenClassification::from_config
             transformers::AutoModelForTokenClassification::from_pretrained
+            transformers::AutoModelForUniversalSegmentation::from_config
+            transformers::AutoModelForUniversalSegmentation::from_pretrained
             transformers::AutoModelForVideoClassification::from_config
             transformers::AutoModelForVideoClassification::from_pretrained
             transformers::AutoModelForVision2Seq::from_config
             transformers::AutoModelForVision2Seq::from_pretrained
             transformers::AutoModelForVisualQuestionAnswering::from_config
             transformers::AutoModelForVisualQuestionAnswering::from_pretrained
+            transformers::AutoModelForZeroShotImageClassification::from_config
+            transformers::AutoModelForZeroShotImageClassification::from_pretrained
             transformers::AutoModelForZeroShotObjectDetection::from_config
             transformers::AutoModelForZeroShotObjectDetection::from_pretrained
             transformers::AutoModelWithLMHead::from_config
@@ -152,6 +156,7 @@ library under the corresponding class from the `torch <torch.html>`_ integration
             transformers::constant_with_warmup
             transformers::cosine
             transformers::cosine_with_restarts
+            transformers::inverse_sqrt
             transformers::linear
             transformers::polynomial
 
