@@ -3,7 +3,8 @@ Built-in :class:`~tango.step.Step` implementations that are not tied to any part
 integration.
 """
 
-__all__ = ["DatasetCombineStep", "DatasetRemixStep", "PrintStep"]
+__all__ = ["DatasetCombineStep", "DatasetRemixStep", "PrintStep", "ShellStep"]
 
 from .dataset_remix import DatasetCombineStep, DatasetRemixStep
 from .print import PrintStep
+from .shell_step import ShellStep
